@@ -35,5 +35,7 @@ def dustjs(parser, token):
     bits = token.contents.split()
     if len(bits) not in [2, 3]:
         raise template.TemplateSyntaxError(
-            "'dustjs' tag takes one argument: the name/id of the template")
-    return DustJSNode(bits[1])
+            "'dustjs' tag takes either (1) one argument: the name/id of "
+            "the template, or (2)  two arguments: the name of a subdirectory "
+            "to search and a regular expression of files to search for")
+    return DustJSNode(*bits[1:])
