@@ -42,5 +42,7 @@ def mustachejs(parser, token):
     bits = token.contents.split()
     if len(bits) not in [2, 3]:
         raise template.TemplateSyntaxError(
-            "'mustachejs' tag takes one argument: the name/id of the template")
-    return MustacheJSNode(bits[1])
+            "'mustachejs' tag takes either (1) one argument: the name/id of "
+            "the template, or (2)  two arguments: the name of a subdirectory "
+            "to search and a regular expression of files to search for")
+    return MustacheJSNode(*bits[1:])
